mc.listen("onJoin", (player) => {
    // 加载 land.json 数据
    var config = new JsonConfigFile("./plugins/eland/land.json");
    const CreateLand = ll.import("ILAPI_CreateLand");

    if (!CreateLand) {
        log("无法导入 ILAPI_CreateLand，请检查插件是否正常加载");
        return;
    }

    const xuid = player.xuid; // 玩家唯一标识
    const player_name = player.name; // 玩家名称

    // 获取玩家对应的领地数据
    var playerLands = config.get(player_name);

    if (!playerLands || playerLands.length === 0) {
        log(`玩家 ${player_name} 在 land.json 中没有领地数据`);
        return;
    }

    // 遍历玩家的每个领地数据并迁移
    playerLands.forEach((landObject, index) => {
        // landObject 是一个包含单个领地名键值对的对象
        for (let landName in landObject) {
            let land = landObject[landName];
            try {
                // 检查 land.posa 和 land.posb 是否有效
                if (!land.posa || !land.posb) {
                    log(`玩家 ${player_name} 的领地 ${landName} 缺少 posa 或 posb，跳过迁移`);
                    continue;
                }

                // 解析位置信息
                const posA = parsePosition(land.posa);
                const posB = parsePosition(land.posb);

                // 转换维度
                const dimid = convertDimension(land.dim);
                if (dimid === null) {
                    log(`玩家 ${player_name} 的领地 ${landName} 的维度无效: ${land.dim}`);
                    continue;
                }

                // 调用创建领地 API
                const landId = CreateLand(xuid, posA, posB, dimid);

                if (landId !== -1) {
                    log(`玩家 ${player_name} 的领地 ${landName} 迁移成功，领地 ID: ${landId}`);
                } else {
                    log(`玩家 ${player_name} 的领地 ${landName} 迁移失败，请检查范围或其他参数`);
                }
            } catch (error) {
                log(`玩家 ${player_name} 的领地 ${landName} 迁移时发生错误: ${error.message}`);
            }
        }
    });

    // 删除迁移完成的玩家数据并保存到 land.json
    config.delete(player_name); // 删除当前玩家的领地数据
    config.close(); // 保存文件
    log(`玩家 ${player_name} 的领地数据已从 land.json 中移除`);
});

/**
 * 解析位置字符串 "x, y, z" 为 {x: x, y: y, z: z}
 * @param {string} posStr
 * @returns {{x: number, y: number, z: number}}
 */
function parsePosition(posStr) {
    if (!posStr) {
        throw new Error("无效的坐标字符串: " + posStr);
    }
    const parts = posStr.split(",").map((n) => parseFloat(n.trim()));
    if (parts.length !== 3 || parts.some(isNaN)) {
        throw new Error("坐标解析失败: " + posStr);
    }
    return { x: parts[0], y: parts[1], z: parts[2] };
}

/**
 * 将维度名称转换为 iLand 的 dimid
 * @param {string} dim
 * @returns {number|null}
 */
function convertDimension(dim) {
    switch (dim) {
        case "Overworld":
            return 0; // 主世界
        case "Nether":
            return 1; // 地狱
        case "TheEnd":
            return 2; // 末地
        default:
            return null; // 无效维度
    }
}
